@@ -72,6 +72,7 @@ class ConfigurationDescription(common.Serialized):
         self.installables = {}
         self.package_description = None
         self.__load(path)
+        os.environ['AUTOBUILD_CONFIG_FILE'] = os.path.basename(self.path)
  
     def absolute_path(self, path):
         """
@@ -356,6 +357,7 @@ class ArchiveDescription(common.Serialized):
     Describes a dowloadable archive of artifacts for this package.
     
     Attributes:
+        format
         hash
         hash_algorithm
         url
@@ -363,6 +365,7 @@ class ArchiveDescription(common.Serialized):
     # Implementations for various values of hash_algorithm should be found in
     # hash_algorithms.py.
     def __init__(self, dictionary = None):
+        self.format = None
         self.hash = None
         self.hash_algorithm = None
         self.url = None
